@@ -14,7 +14,7 @@
 #
 #  @author Marcello Stanisci
 
-from django.conf.urls import url
+from django.conf.urls import include, url
 from . import user
 from . import funds
 from . import views
@@ -22,17 +22,17 @@ from . import history
 from . import captcha
 
 urlpatterns = [
-    url(r'^$', views.home_page),
+    url(r'^', include('talerbank.urls')),
+    url(r'^(?P<js>(use_js|no_js))?$', views.home_page, name='index'),
     url(r'^favicon\.ico$', views.ignore),
     url(r'^accounts/register/$', user.register_process, name="register"),
     url(r'^accounts/login/$', views.home_page, name="login"),
     url(r'^accounts/logout/$', user.logout_process, name="logout"),
     url(r'^profile$', views.profile_page, name="profile"),
-    url(r'^withdraw$', funds.withdraw_process),
+    url(r'^withdraw$', funds.withdraw_nojs, name="withdraw-nojs"),
     url(r'^public-accounts/details$', user.view_public_accno_process),
     url(r'^public-accounts$', history.public_accounts_process, name="public-history"),
     url(r'^pin/question$', captcha.pin_tan_question, name="pin_tan"),
     url(r'^pin/verify$', captcha.pin_tan_verify),
-    url(r'^admin/add/incoming$', funds.add_incoming, name="add-incoming"),
     url(r'^javascript$', views.javascript_licensing)
     ]
